<?php
/**
Submits pictures from My Coloring Book for an online coloring contest.

Accepts post from My Coloring Book initially with following post variables...
 * name: name of jpeg file for the posted picture.
 * page: name of the original coloring page

Gathers information from entrant to include as part of contest.

Posted data and user-entered data are sent back to the script to validate 
and save.

After successful validation, the repost saves the posted picture and other 
information to the moderation queue, then sends an email to the moderator.
 **/
require_once 'util.php';
require_once 'form.php';
require_once 'contsettings.php';
require_once 'contdata.php';

// Request variables
$action = req('action');
$page = req('page');
$msg = '';
$saved = $action == ACT_ENTER;
// Posted from entry form
if ($saved) {
    // Get entries
    $imgfile = req('imgfile');
    $key = req('key');
    $imgw = intVal(req(FN_IMGW));
    $imgh = intVal(req(FN_IMGH));
    $tnw = intVal(req(FN_TNW));
    $tnh = intVal(req(FN_TNH));
    $tnfile = req('tnfile');
    $person = req(FN_PERSON);
    $email = req(FN_EMAIL);
    $ip = req(FN_IP);
    $age = req(FN_AGE);
    $loc = req(FN_LOC);
    $desc = req(FN_DESC);
    $terms = req(FN_TERMS);

    // Validate
    $focus = '';
    if ($person == '') {
        $msg .= '<li>' . FLD_PERSON . ' is required.</li>';
        if (!$focus) $focus = FN_PERSON;
    }
    if ($email == '') {
        $msg .= '<li>' . FLD_EMAIL . ' is required.</li>';
        if (!$focus) $focus = FN_EMAIL;
    }
    if (intval($age) <= 0) {
        $msg .= '<li>' . FLD_AGE . ' is required.</li>';
        if (!$focus) $focus = FN_AGE;
    }
    if ($loc == '') {
        $msg .= '<li>' . FLD_LOC . ' is required.</li>';
        if (!$focus) $focus = FN_LOC;
    }
    if ($terms <= '') {
        $msg .= '<li>You must read and agree to the terms and conditions.</li>';
        if (!$focus) $focus = FN_TERMS;
    }

    $saved = ($msg == '');
    if ($saved) {
        // Put form variables into a contest item and save
        $cont = new ContData(DIR_QUEUE);
        $cont->key = $key;
        $cont->date = time();
        $cont->person = $person;
        $cont->email = $email;
        $cont->ip = $ip;
        $cont->age = intval($age);
        $cont->loc = $loc;
        $cont->desc = $desc;
        $cont->imgw = $imgw;
        $cont->imgh = $imgh;
        $cont->tnw = $tnw;
        $cont->tnh = $tnh;
        $cont->save();

        // Move the image file to the moderation queue
        $cont->moveImagesFrom($imgfile, $tnfile);

        // Get new file locations into local vars
        $imgfile = $cont->imgfile();
        $tnfile = $cont->tnfile();

        // Send the activation email (moderation)
        $cont->sendEntryEmail();
    }
}
    // Posted from My Coloring Book
else {
    $imgfile = '../' . req('name');
    $key = basename($imgfile, '.jpeg');
    $imgw = intVal(req('imgWidth'));
    $imgh = intVal(req('imgHeight'));
    list($tnw, $tnh) = scaleToFit($imgw, $imgh, THUMBNAIL_WIDTH, THUMBNAIL_HEIGHT);
    $tnfile = makeThumbNail($imgfile, $imgw, $imgh, $tnw, $tnh);
    $person = DEF_PERSON;
    $email = DEF_EMAIL;
    $age = DEF_AGE;
    $loc = DEF_LOC;
    $desc = DEF_DESC;

    $focus = FN_PERSON;
}
?>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">
<html xmlns="http://www.w3.org/1999/xhtml" xml:lang="en" lang="en"
      xmlns:fb="http://www.facebook.com/2008/fbml">
<head>
    <title>Enter Coloring Page in <?php echo CONTEST_TITLE; ?></title>
    <link rel="stylesheet" type="text/css" href="contest.css"/>
    <link rel="stylesheet" type="text/css" href="form.css"/>
    <script type="text/javascript">
        function setFocus() {
            var contform = document.getElementById('contform');
            if (contform) {
                contform['<?php echo $focus; ?>'].focus();
            }
        }
    </script>
</head>
<body onload="setFocus();">
<div id="main">
    <div id="tn"><img src="<?php echo $tnfile; ?>" width="<?php echo $tnw;?>" height="<?php echo $tnh;?>"></div>
    <div id="tninfo">
<?php
if (STATUS == STATUS_NOTSTARTED) {
    include('precontest.php');
    echo '<div id="close"><input type=button class="btn" value="Close This Window" onclick="javascript:window.close();"></div>';
} else if (STATUS == STATUS_ENDED) {
    include('postcontest.php');
    echo '<div id="close"><input type=button class="btn" value="Close This Window" onclick="javascript:window.close();"></div>';
} else if ($saved) {
    include('entered.php');
    echo '<div id="close"><input type=button class="btn" value="Close This Window" onclick="javascript:window.close();"></div>';
} else {
    if ($msg) {
        echo '<h1>Entry form not complete</h1>'
             . '<p>Please correct the following...</p><ul>'
             . $msg . '</ul>';
    } else {
        include('entering.php');
    }
    formBegin('contform', 'contentry.php');
    formRow(FN_PERSON, FLD_PERSON, $person, FT_TEXT_MEDIUM);
    formRow(FN_EMAIL, FLD_EMAIL, $email, FT_TEXT_LARGE);
    formRow(FN_AGE, FLD_AGE, $age, FT_NUMBER);
    formRow(FN_LOC, FLD_LOC, $loc, FT_TEXT_MEDIUM);
    formRow(FN_DESC, FLD_DESC, $desc, FT_TEXT_AREA);
    formRow(FN_TERMS, FLD_TERMS, false, FT_TERMS);
    formButton(ACT_ENTER);
    // Also, pass on extra variables to next script (contsave.php)
    formHidden('ip', $_SERVER['REMOTE_ADDR']);
    formHidden('key', $key);
    formHidden('imgfile', $imgfile);
    formHidden('imgw', $imgw);
    formHidden('imgh', $imgh);
    formHidden('tnfile', $tnfile);
    formHidden('tnw', $tnw);
    formHidden('tnh', $tnh);
    formEnd();
}
?>
    </div>
</div>
</body>
</html>
